@@ -12,16 +12,6 @@ our @EXPORT_OK = qw(compare_feeds);
 
 Feed::PhaseCheck
 
-=head1 VERSION
-
-Version 0.01
-
-=cut
-
-our $VERSION = '0.01';
-
-=head1 SYNOPSIS
-
 Finds the relative time delay between two feed segments.  
 
 Accomplished by shifting one feed relative to the other and then computing the error (absolute difference).  
@@ -30,6 +20,35 @@ The shift that yields the lowest error corresponds to the relative delay between
 
 The output consists of the delay found, and the error in delayed point.
 
+=head1 VERSION
+
+Version 0.02
+
+
+=cut
+
+our $VERSION = '0.02';
+
+=head1 SYNOPSIS
+
+    use Feed::PhaseCheck qw(compare_feeds);
+    my $sample = {
+        "1451276654" => "1.097655",
+        "1451276655" => "1.09765",
+        ...
+        "1451276763" => "1.0976",
+        "1451276764" => "1.097595"
+    };
+    my $compare_to = {
+        "1451276629" => "1.09765",
+        "1451276630" => "1.09764916666667",
+        ...
+        "1451276791" => "1.097595",
+        "1451276792" => "1.097595"
+    }
+    my $max_delay_check = 30;    # seconds
+    my ($errors,$delay_with_min_err) = compare_feeds($sample,$compare_to,$max_delay_check);
+
 =cut
 
 sub compare_feeds {
